==> lire_1.5.orig.tar.gz: lire-1.5/print/po/lire-print.pot.pl <==
# REFERENCE: print.cfg
__( q{Printer Report} );
# REFERENCE: print.cfg
__( q{Printer Accounting Report} );
# REFERENCE: schema:print
__( q{DLF Schema for Print service} );
# REFERENCE: schema:print
__( q{Each record in a the <structname>print</structname> schema
   contains the information about one print job.
  } );
# REFERENCE: schema:print
__( q{Timestamp} );
# REFERENCE: schema:print
__( q{The time at which the print job started printing.} );
# REFERENCE: schema:print
__( q{Duration} );
# REFERENCE: schema:print
__( q{The time the print job took to print.} );
# REFERENCE: schema:print
__( q{Client Host} );
# REFERENCE: schema:print
__( q{The client hostname (or ip address) that requested the print
   job.
  } );
# REFERENCE: schema:print
__( q{User} );
# REFERENCE: schema:print
__( q{The name of the user who requested the print job.} );
# REFERENCE: schema:print
__( q{Job ID} );
# REFERENCE: schema:print
__( q{The identifier assigned to the job by the printing system. No
    uniqueness constraint are placed on this field. For example, it is
    possible for a printing system to reset the job identifiers after
    each restart of the system.
   } );
# REFERENCE: schema:print
__( q{Printer} );
# REFERENCE: schema:print
__( q{The printer's name on which the job was printed.} );
# REFERENCE: schema:print
__( q{Copies} );
# REFERENCE: schema:print
__( q{The number of copies of the job that were printed.} );
# REFERENCE: schema:print
__( q{Pages} );
# REFERENCE: schema:print
__( q{The number of pages contained in the requested print job
    <emphasis>not counting the copies</emphasis>, i.e. the number of
    pages in one copies of the print job. } );
# REFERENCE: schema:print
__( q{Job Size} );
# REFERENCE: schema:print
__( q{The size of requested print job.} );
# REFERENCE: schema:print
__( q{Billing ID} );
# REFERENCE: schema:print
__( q{An identifier used to relate the job to an billing account.} );
# REFERENCE: report:print:billing-per-printer
__( q{Billing per Printer Report} );
# REFERENCE: report:print:billing-per-printer
__( q{This report shows the billing totals per printer.} );
# REFERENCE: report:print:billing-per-printer
__( q{Billing per Printer} );
# REFERENCE: report:print:billing-per-printer
__( q{Pages} );
# REFERENCE: report:print:billing-per-printer
__( q{% Total} );
# REFERENCE: report:print:billing-per-printer
__( q{% Group} );
# REFERENCE: report:print:billing
__( q{Billing Report} );
# REFERENCE: report:print:billing
__( q{This report shows the billing totals.} );
# REFERENCE: report:print:billing
__( q{Billing Totals} );
# REFERENCE: report:print:jobs-per-period
__( q{Jobs per Period Print Report} );
# REFERENCE: report:print:jobs-per-period
__( q{This report lists the number of jobs during different periods.} );
# REFERENCE: report:print:jobs-per-period
__( q{This parameter controls the time period over which the
     jobs are aggregated.
    } );
# REFERENCE: report:print:jobs-per-period
__( q{Jobs by $period} );
# REFERENCE: report:print:jobs-per-period
__( q{Period} );
# REFERENCE: report:print:jobs-per-period
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-period
__( q{% Total} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{Jobs per Printer per Period Print Report} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{This report lists the daily total of jobs for each printer.} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{This parameter controls the time period over which the
     jobs are aggregated.
    } );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{Jobs per Printer by $period} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{Period} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{% Total} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{% Period} );
# REFERENCE: report:print:jobs-per-printer
__( q{Jobs per Printer Print Report} );
# REFERENCE: report:print:jobs-per-printer
__( q{This report shows the number of jobs for each printer.} );
# REFERENCE: report:print:jobs-per-printer
__( q{Jobs By Printer} );
# REFERENCE: report:print:jobs-per-printer
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-printer
__( q{% Total} );
# REFERENCE: report:print:jobs-per-sheets
__( q{Number Of Jobs For Each Number Of Sheets} );
# REFERENCE: report:print:jobs-per-sheets
__( q{This report shows the number of jobs sorted by the
   number of sheets in them.} );
# REFERENCE: report:print:jobs-per-sheets
__( q{This parameter controls the number of sheets into
     which the jobs are aggregated.
    } );
# REFERENCE: report:print:jobs-per-sheets
__( q{Jobs per Number of Sheets} );
# REFERENCE: report:print:jobs-per-sheets
__( q{Sheets} );
# REFERENCE: report:print:jobs-per-sheets
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-sheets
__( q{% Total} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{Jobs per User per Period Print Report} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{This report lists the daily total of jobs per user for each
    printer.} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{This parameter controls the time period over which the
     usage is aggregated.
    } );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{Jobs per User per Printer by $period} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{Period} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{% Total} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{% Group} );
# REFERENCE: report:print:sheets-per-period
__( q{Sheets per Period Print Report} );
# REFERENCE: report:print:sheets-per-period
__( q{This report shows the number of sheets split into periods.} );
# REFERENCE: report:print:sheets-per-period
__( q{This parameter controls the time period over which the
     sheets are aggregated.
    } );
# REFERENCE: report:print:sheets-per-period
__( q{Sheets Per Period} );
# REFERENCE: report:print:sheets-per-period
__( q{Period} );
# REFERENCE: report:print:sheets-per-period
__( q{Sheets} );
# REFERENCE: report:print:sheets-per-period
__( q{% Total} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{Sheets per User per Period Print Report} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{This report shows the number of sheets printed by each user spliced
  out into periods.} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{This parameter controls the time period over which the
     sheets are aggregated.
    } );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{Sheets Per User Per Period} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{Period} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{Sheets} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{% Total} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{% Group} );
# REFERENCE: report:print:sheets-per-user
__( q{Sheets per User Print Report} );
# REFERENCE: report:print:sheets-per-user
__( q{This report shows the number of sheets printed by each user.} );
# REFERENCE: report:print:sheets-per-user
__( q{Sheets Per User} );
# REFERENCE: report:print:sheets-per-user
__( q{Sheets} );
# REFERENCE: report:print:sheets-per-user
__( q{% Total} );
# REFERENCE: report:print:top-users
__( q{Top Users Print Report} );
# REFERENCE: report:print:top-users
__( q{This report lists the users with the most print jobs.} );
# REFERENCE: report:print:top-users
__( q{This parameter controls the number of users to
     display in the report.
    } );
# REFERENCE: report:print:top-users
__( q{Number of Jobs by Users, Top $users_to_show} );
# REFERENCE: report:print:top-users
__( q{Jobs} );
# REFERENCE: report:print:top-users
__( q{% Total} );

==> lire_2.1.1.orig.tar.gz: lire-2.1.1/print/po/lire-print.pot.pl <==
# REFERENCE: print_default.xml
__( q{Printer Report} );
# REFERENCE: print_default.xml
__( q{Printer Accounting Report} );
# REFERENCE: schema:print
__( q{DLF Schema for Print service} );
# REFERENCE: schema:print
__( q{Each record in a the <structname>print</structname> schema contains the information about one print job. } );
# REFERENCE: schema:print
__( q{Timestamp} );
# REFERENCE: schema:print
__( q{The time at which the print job started printing.} );
# REFERENCE: schema:print
__( q{Duration} );
# REFERENCE: schema:print
__( q{The time the print job took to print.} );
# REFERENCE: schema:print
__( q{Client Host} );
# REFERENCE: schema:print
__( q{The client hostname (or ip address) that requested the print job. } );
# REFERENCE: schema:print
__( q{User} );
# REFERENCE: schema:print
__( q{The name of the user who requested the print job.} );
# REFERENCE: schema:print
__( q{Job ID} );
# REFERENCE: schema:print
__( q{The identifier assigned to the job by the printing system. No uniqueness constraint are placed on this field. For example, it is possible for a printing system to reset the job identifiers after each restart of the system. } );
# REFERENCE: schema:print
__( q{Printer} );
# REFERENCE: schema:print
__( q{The printer's name on which the job was printed.} );
# REFERENCE: schema:print
__( q{Copies} );
# REFERENCE: schema:print
__( q{The number of copies of the job that were printed.} );
# REFERENCE: schema:print
__( q{Pages} );
# REFERENCE: schema:print
__( q{The number of pages contained in the requested print job <emphasis>not counting the copies</emphasis>, i.e. the number of pages in one copies of the print job.} );
# REFERENCE: schema:print
__( q{Job Size} );
# REFERENCE: schema:print
__( q{The size of requested print job.} );
# REFERENCE: schema:print
__( q{Billing ID} );
# REFERENCE: schema:print
__( q{An identifier used to relate the job to an billing account.} );
# REFERENCE: report:print:billing-per-printer
__( q{Billing per Printer Report} );
# REFERENCE: report:print:billing-per-printer
__( q{This report shows the billing totals per printer.} );
# REFERENCE: report:print:billing-per-printer
__( q{Billing per Printer} );
# REFERENCE: report:print:billing-per-printer
__( q{Pages} );
# REFERENCE: report:print:billing-per-printer
__( q{% Total} );
# REFERENCE: report:print:billing-per-printer
__( q{% Group} );
# REFERENCE: report:print:billing
__( q{Billing Report} );
# REFERENCE: report:print:billing
__( q{This report shows the billing totals.} );
# REFERENCE: report:print:billing
__( q{Billing Totals} );
# REFERENCE: report:print:jobs-per-period
__( q{Jobs per Period Print Report} );
# REFERENCE: report:print:jobs-per-period
__( q{This report lists the number of jobs during different periods.} );
# REFERENCE: report:print:jobs-per-period
__( q{This parameter controls the time period over which the jobs are aggregated. } );
# REFERENCE: report:print:jobs-per-period
__( q{Jobs by $period} );
# REFERENCE: report:print:jobs-per-period
__( q{Period} );
# REFERENCE: report:print:jobs-per-period
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-period
__( q{% Total} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{Jobs per Printer per Period Print Report} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{This report lists the daily total of jobs for each printer.} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{This parameter controls the time period over which the jobs are aggregated. } );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{Jobs per Printer by $period} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{Period} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{% Total} );
# REFERENCE: report:print:jobs-per-printer-per-period
__( q{% Period} );
# REFERENCE: report:print:jobs-per-printer
__( q{Jobs per Printer Print Report} );
# REFERENCE: report:print:jobs-per-printer
__( q{This report shows the number of jobs for each printer.} );
# REFERENCE: report:print:jobs-per-printer
__( q{Jobs By Printer} );
# REFERENCE: report:print:jobs-per-printer
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-printer
__( q{% Total} );
# REFERENCE: report:print:jobs-per-sheets
__( q{Number Of Jobs For Each Number Of Sheets} );
# REFERENCE: report:print:jobs-per-sheets
__( q{This report shows the number of jobs sorted by the number of sheets in them.} );
# REFERENCE: report:print:jobs-per-sheets
__( q{This parameter controls the number of sheets into which the jobs are aggregated. } );
# REFERENCE: report:print:jobs-per-sheets
__( q{Jobs per Number of Sheets} );
# REFERENCE: report:print:jobs-per-sheets
__( q{Sheets} );
# REFERENCE: report:print:jobs-per-sheets
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-sheets
__( q{% Total} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{Jobs per User per Period Print Report} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{This report lists the daily total of jobs per user for each printer.} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{This parameter controls the time period over which the usage is aggregated. } );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{Jobs per User per Printer by $period} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{Period} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{Jobs} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{% Total} );
# REFERENCE: report:print:jobs-per-user-per-period
__( q{% Group} );
# REFERENCE: report:print:sheets-per-period
__( q{Sheets per Period Print Report} );
# REFERENCE: report:print:sheets-per-period
__( q{This report shows the number of sheets split into periods.} );
# REFERENCE: report:print:sheets-per-period
__( q{This parameter controls the time period over which the sheets are aggregated. } );
# REFERENCE: report:print:sheets-per-period
__( q{Sheets Per Period} );
# REFERENCE: report:print:sheets-per-period
__( q{Period} );
# REFERENCE: report:print:sheets-per-period
__( q{Sheets} );
# REFERENCE: report:print:sheets-per-period
__( q{% Total} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{Sheets per User per Period Print Report} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{This report shows the number of sheets printed by each user spliced out into periods.} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{This parameter controls the time period over which the sheets are aggregated. } );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{Sheets Per User Per Period} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{Period} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{Sheets} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{% Total} );
# REFERENCE: report:print:sheets-per-user-per-period
__( q{% Group} );
# REFERENCE: report:print:sheets-per-user
__( q{Sheets per User Print Report} );
# REFERENCE: report:print:sheets-per-user
__( q{This report shows the number of sheets printed by each user.} );
# REFERENCE: report:print:sheets-per-user
__( q{Sheets Per User} );
# REFERENCE: report:print:sheets-per-user
__( q{Sheets} );
# REFERENCE: report:print:sheets-per-user
__( q{% Total} );
# REFERENCE: report:print:top-users
__( q{Top Users Print Report} );
# REFERENCE: report:print:top-users
__( q{This report lists the users with the most print jobs.} );
# REFERENCE: report:print:top-users
__( q{This parameter controls the number of users to display in the report. } );
# REFERENCE: report:print:top-users
__( q{Number of Jobs by Users, Top $users_to_show} );
# REFERENCE: report:print:top-users
__( q{Jobs} );
# REFERENCE: report:print:top-users
__( q{% Total} );
